#
# Copyright (C) 2000-2005 by Yasushi Saito (yasushi.saito@gmail.com)
# 
# Pychart is free software; you can redistribute it and/or modify it
# under the terms of the GNU General Public License as published by the
# Free Software Foundation; either version 2, or (at your option) any
# later version.
#
# Pychart is distributed in the hope that it will be useful, but WITHOUT
# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
# FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
# for more details.
#
from pychart import *
import tocslib

def createbar_plot(ar, label, ycol, base, clu):
    baseBar = bar_plot.T(label=None, fill_style = None, line_style=None,
                        data=base, hcol=ycol, cluster=(clu,5))
    bar = bar_plot.T(label=label,
                     fill_style = fill_style.standards.nth(ycol),
                     data=data, hcol=ycol, cluster=(clu,5), stack_on = baseBar)
    ar.add_plot(baseBar, bar)
    
def createGraph(data, base):
    ar = area.T(size=(tocslib.width, tocslib.height),
                x_range = (0.5,3.5),
                x_axis = axis.X(label="/bNumber of nodes with fast disks",
                                tic_interval=lambda x,y: range(1, 3, 1)),
                y_axis = axis.Y(label="/bMessages//second", 
                                label_offset=(tocslib.xlabel_offset, None)),
                legend=legend.T())
    
    createbar_plot(ar, "D4", 2, base, 0)
    createbar_plot(ar, "D2", 1, base, 1)
    createbar_plot(ar, "S4", 5, base, 2)
    createbar_plot(ar, "S2", 4, base, 3)
    createbar_plot(ar, "R", 3, base, 4)
    return ar

base_nonrepl =    [  [0, 791,    778,    693.2, 766.88, 753.09],
                     [1, 791,    778,    693.2, 766.88, 753.09],
                     [2, 791,    778,    693.2, 766.88, 753.09],
                     [3, 791,    778,    693.2, 766.88, 753.09]]
base_repl = [[0, 362.53, 373.34, 325.00, 360.4, 363.23],
             [1, 362.53, 373.34, 325.00, 360.4, 363.23],
             [2, 362.53, 373.34, 325.00, 360.4, 363.23],
             [3, 362.53, 373.34, 325.00, 360.4, 363.23]]

data = chart_data.read_str(" ",
                           "0 0 0 0 0 0 0",
                           "1 45 63 2 9 30",
                           "2 118 133 3 20 53",
                           "3 174 194 3 31 71")
ar = createGraph(data, base_nonrepl)
#area.y_range = (0,200)
ar.y_range = (600,1000)
ar.y_axis.tic_interval=50
ar.legend=None

ar.draw()
tocslib.label(ar, "(a)").draw()

data = chart_data.read_str(" ",
                           "0 0 0 0 0 0 0",
                           "1 10 26.5 2 4 9",
                           "2 29 53 3 10 18",
                           "3 48 79 3 16 28")

ar = createGraph(data, base_repl)
#area.y_range = (0,100)
ar.y_range = (300,500)
ar.y_axis.label=None
ar.y_axis.tic_interval=25
ar.loc = tocslib.loc2
ar.draw()
tocslib.label(ar, "(b)").draw()





#
# Copyright (C) 2000-2005 by Yasushi Saito (yasushi.saito@gmail.com)
# 
# Pychart is free software; you can redistribute it and/or modify it
# under the terms of the GNU General Public License as published by the
# Free Software Foundation; either version 2, or (at your option) any
# later version.
#
# Pychart is distributed in the hope that it will be useful, but WITHOUT
# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
# FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
# for more details.
#
from pychart import *
import tocslib

data = chart_data.read_str(",",
                    "/8No\nReplication,23,105",
                    "/8Replication,9,38",
                    "/8Replication\nwith NVRAM,13,48")

ar = area.T(y_range=(0,150),
            size=(tocslib.width*1.3, tocslib.height),
            x_coord=category_coord.T(data, 0),
            y_axis = axis.Y(label="/bMessages//second", tic_interval=50),
            x_axis = axis.X(label=None),
            legend=legend.T(loc=(70,50)))

ar.add_plot(bar_plot.T(label="With one disk//node",
                       cluster = (0,2), data = data, width=15,
                       fill_style=fill_style.white),
            bar_plot.T(label="With three disks//node",
                       cluster = (1,2), data = data, width=15, hcol=2))

ar.draw()












#
# Copyright (C) 2000-2005 by Yasushi Saito (yasushi.saito@gmail.com)
#
# Pychart is free software; you can redistribute it and/or modify it
# under the terms of the GNU General Public License as published by the
# Free Software Foundation; either version 2, or (at your option) any
# later version.
#
# Pychart is distributed in the hope that it will be useful, but WITHOUT
# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
# FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
# for more details.
#
import sys
import datetime
from pychart import *

def date_to_ordinal(s):
    month, day, year = map(int, s.split("/"))
    return datetime.date(year, month, day).toordinal()

def format_date(ordinal):
    d = datetime.date.fromordinal(int(ordinal))
    return "/a60{}" + d.strftime("%b %d, %y")

data = [["10/5/1983", 10], ["3/5/1984", 15],
        ["11/10/1984", 16], ["2/22/1985", 20]]
data = chart_data.transform(lambda x: [date_to_ordinal(x[0]), x[1]], data)

ar = area.T(x_coord = category_coord.T(data, 0),
            y_range = (0, None),
            x_axis = axis.X(label = "Date", format = format_date),
            y_axis = axis.Y(label = "Value"))
ar.add_plot(bar_plot.T(data = data))
ar.draw()



#
# Copyright (C) 2000-2005 by Yasushi Saito (yasushi.saito@gmail.com)
# 
# Pychart is free software; you can redistribute it and/or modify it
# under the terms of the GNU General Public License as published by the
# Free Software Foundation; either version 2, or (at your option) any
# later version.
#
# Pychart is distributed in the hope that it will be useful, but WITHOUT
# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
# FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
# for more details.
#
from pychart import *

theme.use_color = 1

data1 = [ 0.27027027,  0.74324324,  0.          ,
          0.34459459  ,0.47297297  ,0.06756757,
          0.90540541  ,1.          ,0.40540541  ,
          0.33783784  ,0.33783784  ,0.16216216]
data2 = [ 0.93333333,  0.46666667  ,0.26666667  ,
          0.60666667  ,0.6         ,0.73333333,
          0.22666667,  0.72        ,0.13333333  ,
          0.46666667  ,1.          ,0.29333333]
data = [('/7Model', data1), ('/7Station', data2)]
        
ar = area.T(legend=legend.T(loc=(100,-5), right_fudge=0, left_fudge=3))

plot = rose_plot.T(data=data, sector_centred=True)
ar.add_plot(plot)
ar.draw()




#
# Copyright (C) 2000-2005 by Yasushi Saito (yasushi.saito@gmail.com)
# 
# Pychart is free software; you can redistribute it and/or modify it
# under the terms of the GNU General Public License as published by the
# Free Software Foundation; either version 2, or (at your option) any
# later version.
#
# Pychart is distributed in the hope that it will be useful, but WITHOUT
# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
# FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
# for more details.
#
from pychart import *
theme.get_options()

# We have 10 sample points total.  The first value in each tuple is
# the X value, and subsequent values are Y values for different lines.
data = [(10, 20, 30), (20, 65, 33),
	(30, 55, 30), (40, 45, 51),
	(50, 25, 27), (60, 75, 30),
	(70, 80, 42), (80, 62, 32),
	(90, 42, 39), (100, 32, 39)]

# The format attribute specifies the text to be drawn at each tick mark.
# Here, texts are rotated -60 degrees ("/a-60"), left-aligned ("/hL"),
# and numbers are printed as integers ("%d"). 
xaxis = axis.X(format="/a-60/hL%d", tic_interval = 20, label="Stuff")
yaxis = axis.Y(tic_interval = 20, label="Value")

# Define the drawing area. "y_range=(0,None)" tells that the Y minimum
# is 0, but the Y maximum is to be computed automatically. Without
# y_ranges, Pychart will pick the minimum Y value among the samples,
# i.e., 20, as the base value of Y axis.
ar = area.T(x_axis=xaxis, y_axis=yaxis, y_range=(0,None))

# The first plot extracts Y values from the 2nd column
# ("ycol=1") of DATA ("data=data"). X values are takes from the first
# column, which is the default.
plot = line_plot.T(label="foo", data=data, ycol=1, tick_mark=tick_mark.star)
plot2 = line_plot.T(label="bar", data=data, ycol=2, tick_mark=tick_mark.square)

ar.add_plot(plot, plot2)

# The call to ar.draw() usually comes at the end of a program.  It
# draws the axes, the plots, and the legend (if any).

ar.draw()



#
# Copyright (C) 2000-2005 by Yasushi Saito (yasushi.saito@gmail.com)
# 
# Pychart is free software; you can redistribute it and/or modify it
# under the terms of the GNU General Public License as published by the
# Free Software Foundation; either version 2, or (at your option) any
# later version.
#
# Pychart is distributed in the hope that it will be useful, but WITHOUT
# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
# FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
# for more details.
#
import random
from pychart import *

random.seed(0)
data1 = []
data2 = []
x1 = 0
x2 = 0
for i in range(0, 100, 5):
    x1 += random.randrange(0,3)
    x2 += random.randrange(0,3)
    data1.append([i, x1])
    data2.append([i, x2])

ar = area.T(size = (150, 120),
            x_axis = axis.X(format="%d"),
            y_axis = axis.Y(offset = 0, format="%d"),
            y_axis2 = axis.Y(offset = 150, format="%d", draw_tics_right = 1))

ar.add_plot(line_plot.T(data = data2))
ar.add_plot(bar_plot.T(data = data1))
ar.draw()




#
# Copyright (C) 2000-2005 by Yasushi Saito (yasushi.saito@gmail.com)
# 
# Pychart is free software; you can redistribute it and/or modify it
# under the terms of the GNU General Public License as published by the
# Free Software Foundation; either version 2, or (at your option) any
# later version.
#
# Pychart is distributed in the hope that it will be useful, but WITHOUT
# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
# FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
# for more details.
#
from pychart import *
import sys

data = [("foo", 10),("bar", 20), ("baz", 30), ("ao", 40)]

ar = area.T(size=(150,150), legend=legend.T(),
            x_grid_style = None, y_grid_style = None)

plot = pie_plot.T(data=data, arc_offsets=[0,10,0,10],
                  shadow = (2, -2, fill_style.gray50),
                  label_offset = 25,
                  arrow_style = arrow.a3)
ar.add_plot(plot)
ar.draw()





#
# Copyright (C) 2000-2005 by Yasushi Saito (yasushi.saito@gmail.com)
# 
# Pychart is free software; you can redistribute it and/or modify it
# under the terms of the GNU General Public License as published by the
# Free Software Foundation; either version 2, or (at your option) any
# later version.
#
# Pychart is distributed in the hope that it will be useful, but WITHOUT
# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
# FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
# for more details.
#
from pychart import *
import pychart.doc_support
import chartdemo
import re

x = 100
y = 500

can = canvas.default_canvas()

def draw_rect(color):
    global x, y
    name = pychart.doc_support.stringify_value(color)
    name = re.sub("color\\.", "", name)
    name = pychart.doc_support.break_string(name)
    fill = fill_style.Plain(bgcolor = color)
    can.rectangle(line_style.default, fill, x, y, x+15, y+15)
    height = font.text_height(name)[0] + 5
    tb = text_box.T(text="/hL" + name, loc=(x, y-height), line_style=None)
    x = x + 50
    tb.draw()

for style in color.standards.list():
    if (not theme.use_color and style.r == style.g and style.g == style.b) or \
       theme.use_color:
        draw_rect(style)
        if x >= chartdemo.MaxWidth:
            x=100
            y=y-60




#
# Copyright (C) 2000-2005 by Yasushi Saito (yasushi.saito@gmail.com)
# 
# Pychart is free software; you can redistribute it and/or modify it
# under the terms of the GNU General Public License as published by the
# Free Software Foundation; either version 2, or (at your option) any
# later version.
#
# Pychart is distributed in the hope that it will be useful, but WITHOUT
# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
# FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
# for more details.
#
from pychart import *
can = canvas.default_canvas()
x, y = (100, 500)

def show_text(str):
    global x, y
    can.show(x, y, str)
    can.show(x + 200, y, "/12/C" + font.quotemeta(str))
    y -= 20

show_text("/12/hLLeft align")
show_text("/12/hRRight align")
show_text("/12/hCCenter align")
show_text("/a20/12/hRAngled text")

def show_textv(str):
    global x, y
    can.show(x, y, str)
    x += 150

y -= 40
x = 100
show_textv("/12/vT//12//vTTop align")
show_textv("/12/vM//12//vT/12Middle align")
show_textv("/12/vB//12//vT/12Bottom align")

y -= 40
x = 100
show_text("/16/HHelvetica")
show_text("/12/CCourier")
show_text("/12/NHelvetica-Narrow")
show_text("/12/PPalatino-Roman")
show_text("/12/AAvantgarde")
show_text("/12/T/iTimes-Italic")
show_text("/12/F{ZapfDingbats}ZapfDingbats")




import sys
sys.path.append("..")
sys.path.append("../demos")

import pychart.doc_support
from pychart import *
import list_sources
import re
import dircache
import os
import posixpath

target_dir="examples"
cwd = os.getcwd()

python_path = "python"
if sys.platform == "win32":
    python_path = "c:/Python22/python"

try:
    os.mkdir(target_dir)
except:
    pass

index_fp = open(target_dir + "/index.html", "w")
    
index_fp.write("<head><title>pychart Samples</title></head>\n<body>\n")

for file in list_sources.list_sources("../demos"):
    mo = re.match("^(.*).py$", file)
    assert mo
    basename = mo.group(1)
    pngFile = "%s/%s/%s.png" % (cwd, target_dir, basename)
    smallPngFile = "%s/%s/%s-small.png" % (cwd, target_dir, basename)
    src_file = "%s/%s/%s" % (cwd, target_dir, file)
    os.environ["PYTHONPATH"] = "..:" + os.environ.get("PYTHONPATH", "")
    if not os.access(pngFile, os.R_OK):
        print "Creating ", pngFile
        os.environ["PYCHART_OPTIONS"] = "color=yes scale=3 output=%s" % pngFile
        os.chdir("../demos")
        os.system(python_path + " " + file)
        os.chdir(cwd)

    if not os.access(smallPngFile, os.R_OK):
        print "Creating ", smallPngFile
        os.environ["PYCHART_OPTIONS"] = "color=yes scale=0.6 output=%s" % smallPngFile
        os.chdir("../demos")
        os.system(python_path + " " + file)
        os.chdir(cwd)

    if not os.access(src_file, os.R_OK):
        os.system("cp ../demos/%s %s" % (file, src_file))

    index_fp.write("<p><a href=\"%s.png\"><img src=\"%s-small.png\"></a>\n" % (basename, basename))
    index_fp.write("<p><a href=\"" + basename + ".py\">Source code</a>")

index_fp.write("</body>\n")
index_fp.close()

    




import re
import sys

pats = (
    ("theme.get_options()", "options"),
    ("area.T", "module-area"), 
    ("interval_bar_plot.T", "module-interval-bar-plot"),
    ("bar_plot.T", "module-bar-plot"),
    ("line_plot.T", "module-line-plot"),
    ("range_plot.T", "module-range-plot"),
    ("pie_plot.T", "module-pie-plot"),
    ("color\\.", "module-color"),
    ("line_style\\.", "module-line-style"),
    ("fill_style\\.", "module-fill-style"),
    ("tick_mark\\.", "module-tick-mark"),
    ("log_coord\\.T", "module-coord"),
    ("linear_coord\\.T", "module-coord"),
    ("category_coord\\.T", "module-coord"),
    ("error_bar\\.", "module-error-bar"),
    ("text_box\\.T", "module-text-box"),
    ("arrow\\.T", "module-arrow"),
    ("axis\\.", "module-axis"),
    ("chart_data\\.", "module-chart-data"),
    ("legend\\.", "module-legend"),
    ("theme\\.", "options"),
    ("canvas\\.", "module-canvas"),
    ("zap\\.", "module-zap"),
    )

re_pats = {}
for pat, repl in pats:
    re_pats[re.compile("(" + pat + ")")] = repl

def hackimgref(mo):
    path = mo.group(1)
    i = path.rfind("/")
    path2 = path[(i+1):]
    print >>sys.stderr, "PATH=", path, path2
    return 'SRC="%s"' % path2
    
in_example = False
for l in sys.stdin.readlines():
    l = re.sub('SRC="(/nfs[^\"]+)"', hackimgref, l)
               
    if re.match(".*<pre[^>]*>", l):
        in_example = True
    elif l.find("</pre>") >= 0:
        in_example = False
        
    if not in_example:
        l = re.sub("<head>", """<head><style type="text/css">\npre {background-color: #e0e0e0}\n</style>\n""", l)
        print l,
        continue

    for str, ref in pats:
        l = re.sub("(" + str + ")", "<a href=\"%s.html\">\\1</a>" % ref, l)
        #l = re.sub(str, "<a href=\"%s.html\">\\1</a>" % ref, l)
    print l,
    
        

        
        



#
# Copyright (C) 2000-2005 by Yasushi Saito (yasushi.saito@gmail.com)
#
# Pychart is free software; you can redistribute it and/or modify it
# under the terms of the GNU General Public License as published by the
# Free Software Foundation; either version 2, or (at your option) any
# later version.
#
# Pychart is distributed in the hope that it will be useful, but WITHOUT
# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
# FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
# for more details.
#
from pychart import *
theme.get_options()

data = [(10, 20, 3.0), (20, 65, 2.5),
        (30, 55, 5.0), (40, 45, 3.0), (50, 25, 2.0)]

ar = area.T(x_axis=axis.X(label="X", format="/a-30{}%d", tic_interval=20),
            y_axis = axis.Y())
ar.add_plot(bar_plot.T(data=data,
                       line_style=None, fill_style = fill_style.gray50,
                       error_bar = error_bar.bar2, error_minus_col=2))
ar.draw()



#
# Copyright (C) 2000-2005 by Yasushi Saito (yasushi.saito@gmail.com)
# 
# Pychart is free software; you can redistribute it and/or modify it
# under the terms of the GNU General Public License as published by the
# Free Software Foundation; either version 2, or (at your option) any
# later version.
#
# Pychart is distributed in the hope that it will be useful, but WITHOUT
# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
# FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
# for more details.
#
from pychart import *
import pychart.line_style

theme.get_options()
chartSize = (180, 110)

can = canvas.default_canvas()

font.defaultSize = 9
chart_object.set_defaults(legend.Entry)
xaxis = axis.X(label="Timeline\n(seconds)", label_offset = (120, 30),
               format="/a-30{}%d", tic_interval = 100)

yaxis = axis.Y(label = "Messages//second")

ar = area.T(size=chartSize, x_axis=xaxis, x_range=(0,800),
            y_grid_interval = 100,
            y_axis=yaxis, y_range=(400,700))
ar.legend = legend.T(loc = (ar.loc[0] + chartSize[0]+30,
                            ar.loc[1] + chartSize[1]/2))

data = chart_data.read_csv("failure.csv")
ar.add_plot(line_plot.T(label="no failure", data=data, ycol=4, line_style=line_style.gray50))
ar.add_plot(line_plot.T(label="one failure", data=data, ycol=1))
ar.add_plot(line_plot.T(label="three failures", data=data, ycol=2, line_style=line_style.black_dash2))

ar.draw()

yloc = ar.loc[1] + ar.size[1] + 50
ytip = ar.loc[1] + ar.size[1]
ybot = ar.loc[1]

def describeEvent(seconds, label, off):
    x1 = ar.x_pos(seconds)
    can.line(line_style.black_dash1, x1, ybot, x1, ytip)
    tb = text_box.T(text=label, loc=(x1+off, yloc), shadow=(2,-2,fill_style.gray70))
    tb.add_arrow((x1, ytip))
    tb.draw()
    
describeEvent(300, "Nodes\nfail", -100)
describeEvent(320, "New membership\ndetermined", -50)
describeEvent(600, "Nodes\nrecover", 0)
describeEvent(620, "New membership\ndetermined", 50)



#
# Copyright (C) 2000-2005 by Yasushi Saito (yasushi.saito@gmail.com)
#
# Pychart is free software; you can redistribute it and/or modify it
# under the terms of the GNU General Public License as published by the
# Free Software Foundation; either version 2, or (at your option) any
# later version.
#
# Pychart is distributed in the hope that it will be useful, but WITHOUT
# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
# FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
# for more details.
#
from pychart import *
theme.get_options()

data = [(10, 20, 30, 5), (20, 65, 33, 5),
        (30, 55, 30, 5), (40, 45, 51, 7), (50, 25, 27, 3)]
chart_object.set_defaults(area.T, size = (150, 120), y_range = (0, None),
                          x_coord = category_coord.T(data, 0))
chart_object.set_defaults(bar_plot.T, data = data)

# Draw the 1st graph. The Y upper bound is calculated automatically.
ar = area.T(x_axis=axis.X(label="X label", format="/a-30{}%d"),
            y_axis=axis.Y(label="Y label", tic_interval=10))
ar.add_plot(bar_plot.T(label="foo", cluster=(0, 3)),
            bar_plot.T(label="bar", hcol=2, cluster=(1, 3)),
            bar_plot.T(label="baz", hcol=3, cluster=(2, 3)))
ar.draw()

ar = area.T(legend = legend.T(), loc=(250,0),
            x_axis=axis.X(label="X label", format="/a-30{}%d"),
            y_axis=axis.Y(label="Y label", tic_interval=10))
bar_plot.fill_styles.reset();
plot1 = bar_plot.T(label="foo")
plot2 = bar_plot.T(label="bar", hcol=2, stack_on = plot1)
plot3 = bar_plot.T(label="baz", hcol=3, stack_on = plot2)
ar.add_plot(plot1, plot2, plot3)
ar.draw()



#
# Copyright (C) 2000-2005 by Yasushi Saito (yasushi.saito@gmail.com)
#
# Pychart is free software; you can redistribute it and/or modify it
# under the terms of the GNU General Public License as published by the
# Free Software Foundation; either version 2, or (at your option) any
# later version.
#
# Pychart is distributed in the hope that it will be useful, but WITHOUT
# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
# FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
# for more details.
#
from pychart import *
theme.get_options()

data = [(10, 20, 30, 5), (20, 65, 33, 5), (30, 55, 30, 5), (40, 45, 51, 7),
	(50, 25, 27, 3), (60, 75, 30, 5), (70, 80, 42, 5), (80, 62, 32, 5),
	(90, 42, 39, 5), (100, 32, 39, 4)]

# The attribute y_coord=... tells that the Y axis values
# should be taken from samples.
# In this example, Y values will be [40,50,60,70,80].
ar = area.T(y_coord = category_coord.T(data[3:8], 0),
            x_grid_style=line_style.gray50_dash1,
            x_grid_interval=20, x_range = (0,100),
            x_axis=axis.X(label="X label"),
            y_axis=axis.Y(label="Y label"),
            bg_style = fill_style.gray90,
            border_line_style = line_style.default,
            legend = legend.T(loc=(80,10)))

# Below call sets the default attributes for all bar plots.
chart_object.set_defaults(bar_plot.T, direction="horizontal", data=data)

# Attribute cluster=(0,3) tells that you are going to draw three bar
# plots side by side.  The plot labeled "foo" will the leftmost (i.e.,
# 0th out of 3).  Attribute hcol tells the column from which to
# retrive sample values from.  It defaults to one.
ar.add_plot(bar_plot.T(label="foo", cluster=(0,3)))
ar.add_plot(bar_plot.T(label="bar", hcol=2, cluster=(1,3)))
ar.add_plot(bar_plot.T(label="baz", hcol=3, cluster=(2,3)))
ar.draw()



#
# Copyright (C) 2000-2005 by Yasushi Saito (yasushi.saito@gmail.com)
# 
# Pychart is free software; you can redistribute it and/or modify it
# under the terms of the GNU General Public License as published by the
# Free Software Foundation; either version 2, or (at your option) any
# later version.
#
# Pychart is distributed in the hope that it will be useful, but WITHOUT
# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
# FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
# for more details.
#
from pychart import *
import math

def format_x_axis(x):
    return str(int(x*2/math.pi)) + "//2"
ar = area.T(x_axis=axis.X(label="X (unit is Pi)", format=format_x_axis,
                          tic_interval=math.pi/2.0),
            y_axis = axis.Y(label="Y"),
            y_range=(-1,1), x_range=(0, math.pi*4), legend = legend.T())
sindata = chart_data.func(lambda x: math.sin(x), 0, math.pi*4, 0.1)
cosdata = chart_data.func(lambda x: math.cos(x), 0, math.pi*4, 0.1)
sin2data = chart_data.func(lambda x: math.sin(x)/2, 0, math.pi*4, 0.1)
cos2data = chart_data.func(lambda x: math.cos(x)/2, 0, math.pi*4, 0.1)
ar.add_plot(line_plot.T(label="sin(x)", data=sindata),
            line_plot.T(label="sin(x)//2", data=sin2data),
            line_plot.T(label="cos(x)", data=cosdata),
            line_plot.T(label="cos(x)//2", data=cos2data))
ar.draw()




#
# Copyright (C) 2000-2005 by Yasushi Saito (yasushi.saito@gmail.com)
# 
# Pychart is free software; you can redistribute it and/or modify it
# under the terms of the GNU General Public License as published by the
# Free Software Foundation; either version 2, or (at your option) any
# later version.
#
# Pychart is distributed in the hope that it will be useful, but WITHOUT
# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
# FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
# for more details.
#
from pychart import *

can = canvas.default_canvas()

data = [(10, 20), (20, 65), (30, 55), (40, 45)]

# tic_angle is the angle X values are displayed below the axis.
xaxis = axis.X(label="Stuff")
yaxis = axis.Y(label="Value")

ar = area.T(x_axis=xaxis, y_axis=yaxis)

plot = line_plot.T(label="foo", data=data, xcol=0, ycol=1,
                   tick_mark=tick_mark.star)

ar.add_plot(plot)
can.ellipsis(line_style.T(width=1.5,dash=(4,4)), None, 30, 20, 80, 0.8)
can.clip_ellipsis(30, 20, 80, 0.8)
ar.draw(can)
can.endclip()





import glob
import os.path

def list_sources(dir):
    """Return the list of Python source files under demos/ directory.
    Parameter "dir" specifies the locatino of the demos/ directory."""
    
    l = glob.glob(dir + "/*.py")
    r = []
    for path in l:
        basename = os.path.basename(path)
        if basename in ("tocslib.py", "twographs.py", "chartdemo.py",
                        "list_sources.py"):
            continue
        if basename.startswith(",,"):
            # tla/baz temp file.
            continue
        r.append(basename)
    r.sort()        
    return r

if __name__ == '__main__':
    # When invoked from the cmdline, just print the list of files to
    # the stdout.
    r = list_sources(".")
    print " ".join(r)




#
# Copyright (C) 2000-2005 by Yasushi Saito (yasushi.saito@gmail.com)
#
# Pychart is free software; you can redistribute it and/or modify it
# under the terms of the GNU General Public License as published by the
# Free Software Foundation; either version 2, or (at your option) any
# later version.
#
# Pychart is distributed in the hope that it will be useful, but WITHOUT
# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
# FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
# for more details.
#
from pychart import *
import random
random.seed(0)

def randomdata():
    data = []
    for i in range(0, 30):
        data.append((random.random() * 1000, random.random() * 1000))
    return data

theme.get_options()
chart_object.set_defaults(line_plot.T, line_style=None)

tick1 = tick_mark.Circle(size=2)
tick2 = tick_mark.Circle(size=2, fill_style=fill_style.black)
xaxis = axis.X(label="foo", format="/a-60{}%d")
yaxis = axis.Y(label="bar")

ar = area.T(x_axis=xaxis, y_axis=yaxis,
            x_grid_interval=100, x_grid_style=line_style.gray70_dash3,
            legend = legend.T(loc=(350, 50)), loc = (0, 0))

ar.add_plot(line_plot.T(label="plot1", data=randomdata(), tick_mark=tick1))
ar.add_plot(line_plot.T(label="plot2", data=randomdata(), tick_mark=tick2))
ar.draw()

xaxis = axis.X(label="foo", format="/a-30{}%d")
yaxis = axis.Y(label="bar")
ar = area.T(x_axis=xaxis, y_axis=yaxis,
            x_coord=log_coord.T(), y_coord=log_coord.T(), loc = (200, 0),
            legend = None)

ar.add_plot(line_plot.T(label="plot1", data=randomdata(), tick_mark=tick1))
ar.add_plot(line_plot.T(label="plot2", data=randomdata(), tick_mark=tick2))
ar.draw()



#
# Copyright (C) 2000-2005 by Yasushi Saito (yasushi.saito@gmail.com)
# 
# Pychart is free software; you can redistribute it and/or modify it
# under the terms of the GNU General Public License as published by the
# Free Software Foundation; either version 2, or (at your option) any
# later version.
#
# Pychart is distributed in the hope that it will be useful, but WITHOUT
# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
# FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
# for more details.
#
from pychart import *
import tocslib

data = chart_data.read_str(" ",
                    "2 663.8954 466.1732719",
                    "4 1136.591805 767.7338263",
                    "8 1975.892086 1562.30366",      
                    "16 3095.491197 2401.061551",
                    "30 4838.670793 3836.058")

ar = area.T(size=(tocslib.width2, tocslib.height),
            x_axis = axis.X(label="/bCluster size"),
            y_axis = axis.Y(label="/bMessages//second", tic_interval=1000,
                            label_offset=(tocslib.xlabel_offset*1.2, None)),
            legend=legend.T())
ar.add_plot(line_plot.T(label="No replication",
                        tick_mark=tocslib.get_tick_mark("PN"),
                        line_style=tocslib.get_line_style("PN"),
                        data=data, ycol=1),
             line_plot.T(label="With replication",
                        tick_mark=tocslib.get_tick_mark("PR"),
                        line_style=tocslib.get_line_style("PR"),
                        data=data, ycol=2))

ar.draw()




#
# Copyright (C) 2000-2005 by Yasushi Saito (yasushi.saito@gmail.com)
# 
# Pychart is free software; you can redistribute it and/or modify it
# under the terms of the GNU General Public License as published by the
# Free Software Foundation; either version 2, or (at your option) any
# later version.
#
# Pychart is distributed in the hope that it will be useful, but WITHOUT
# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
# FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
# for more details.
#
from pychart import *

tb = text_box.T(loc=(100,100), text="Without frame")
tb.add_arrow((50, 100))
tb.add_arrow((180, 100))
tb.draw()

tb = text_box.T(loc=(100,130), text="/hCMulti\n/bLine")
tb.add_arrow((50, 120))
tb.add_arrow((180, 100))
tb.draw()

tb = text_box.T(loc=(100,160), text="Fat arrow", line_style=None)
tb.add_arrow((180, 140), tail='rm', arrow = arrow.fat1)
tb.draw()

text_box.T(loc=(180, 100), text="/a90Funny background",
           fill_style = fill_style.gray70).draw()

text_box.T(loc=(180, 140), text="/hL/20Big/oText\n/24/bHuge/oText",
           fill_style = None).draw()




#
# Copyright (C) 2000-2005 by Yasushi Saito (yasushi.saito@gmail.com)
# 
# Pychart is free software; you can redistribute it and/or modify it
# under the terms of the GNU General Public License as published by the
# Free Software Foundation; either version 2, or (at your option) any
# later version.
#
# Pychart is distributed in the hope that it will be useful, but WITHOUT
# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
# FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
# for more details.
#
from pychart import *
import random
random.seed(0)
theme.get_options()

can = canvas.default_canvas()

class zap_x_coord(linear_coord.T):
    # Method get_data_range is inherited from linear_coord.T.
    def get_canvas_pos(self, size, val, min, max):
        # Zap X values between 15 and 35.
        if val <= 15:
            return linear_coord.T.get_canvas_pos(self, size, val, 0, 30)
        elif val <= 35:
            return linear_coord.T.get_canvas_pos(self, size, 15, 0, 30)
        else:
            return linear_coord.T.get_canvas_pos(self, size, val - 20, 0, 30)
        
    def get_tics(self, min, max, interval):
        # Don't draw tick marks between 20 and 30.
        tics = linear_coord.T.get_tics(self, min, max, interval)
        newtics = []
        
        # XXX should be using for..if construction ..
        for item in tics:
            if item < 20 or item > 30:
                newtics.append(item)
        return newtics

data = map(lambda x: (x, random.random() * 2 * x, random.random() * 4 * x),
           range(1,50))

ar = area.T(x_axis = axis.X(label = "X"),
            x_coord = zap_x_coord(),
            y_axis = axis.Y(label = "Y"))
ar.add_plot(line_plot.T(label = "foo", data = data, ycol = 1),
            line_plot.T(label = "bar", data = data, ycol = 2))
ar.draw()

            
zap.zap_vertically(can, line_style.default, fill_style.white,
                   ar.x_pos(14), ar.y_pos(0),
                   ar.x_pos(14) + 6, ar.y_pos(200),
                   4, 6)

                     




#
# Copyright (C) 2000-2005 by Yasushi Saito (yasushi.saito@gmail.com)
# 
# Pychart is free software; you can redistribute it and/or modify it
# under the terms of the GNU General Public License as published by the
# Free Software Foundation; either version 2, or (at your option) any
# later version.
#
# Pychart is distributed in the hope that it will be useful, but WITHOUT
# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
# FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
# for more details.
#
from pychart import *
import sys

theme.get_options()

can = canvas.default_canvas()
size = (300, 200)
ar = area.T(size = size, legend=None, y_range = (9000, 9500),
            x_axis = axis.X(format="7//%d//2002", label="Date"),
            y_axis = axis.Y(format="%d", label="Dow Jones"))
ar.add_plot(line_plot.T(data=[ [1,9379], [2, 9054], [3, 9007], [4, 9109], [5, 9243] ]))
            
ar.draw()
can.show(ar.x_pos(4), ar.y_pos(9070), "/a45{}Dow Jones")

ar = area.T(size = size, legend=None, y_range = (940, 990),
            x_axis = None, y_axis = axis.Y(format="%d", offset=300, tic_len=-6,
                                           label_offset=(50, 0),
                                           label="S&P 500"))
ar.add_plot(line_plot.T(data=[ [1,989], [2, 953], [3, 948], [4, 968], [5, 989] ]))
            
ar.draw()

can.show(ar.x_pos(4), ar.y_pos(970), "/a50{}S&P 500")







#
# Copyright (C) 2000-2005 by Yasushi Saito (yasushi.saito@gmail.com)
#
# Pychart is free software; you can redistribute it and/or modify it
# under the terms of the GNU General Public License as published by the
# Free Software Foundation; either version 2, or (at your option) any
# later version.
#
# Pychart is distributed in the hope that it will be useful, but WITHOUT
# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
# FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
# for more details.
#
from pychart import *
theme.get_options()
data = [["Jan", 10], ["Feb", 22], ["Mar", 30]]

ar = area.T(x_coord = category_coord.T(data, 0), y_range = (0, None),
            x_axis = axis.X(label="Month"),
            y_axis = axis.Y(label="Value"))
ar.add_plot(bar_plot.T(data = data, label = "Something"))
ar.draw()



from pychart import *
import pychart.doc_support
import optik
import string
import sys
import re

parser = optik.OptionParser()
parser.add_option("-S", "--ps", action="store_true", default=None)
parser.add_option("-D", "--pdf", action="store_true", default=None)
parser.add_option("-X", "--pychart-dir", action="store", default=None)
opt, argv = parser.parse_args(sys.argv[1:])

ftype = "png"
pychart_dir = ".."

if opt.ps:
    ftype="pdf"
elif opt.pdf:
    ftype="eps"
if opt.pychart_dir:
    pychart_dir = opt.pychart_dir

def resubfunc(mo):
    typename = re.sub("_", "-", mo.group(1))
    return "\\xref{module-%s}" % typename

def xxx(mo):
    xx = "var"
    return "\\" + xx + "{" + mo.group(1) + "}"

def format_doc_string(str):
    str = re.sub("<<([^>]+)>>", resubfunc, str)
    str = re.sub("<([^>]+)>", xxx, str)
    str = re.sub("\|([^|]+)\|", "\\code{\\1}", str)
    str = str.replace("#", "\\#")
    str = str.replace("%", "\\%")
    str = str.replace("@pxref", "\\pxref")
    str = str.replace("@xref", "\\xref")
    str = str.replace("@code", "\\code")
    str = str.replace("@samp", "\\code")
    str = str.replace("@var", "\\var")
    str = str.replace("@example", "\\begin{verbatim}")
    str = str.replace("@end example", "\\end{verbatim}")
    str = re.sub("@cindex ([^\n]+)", "\\index{\\1}", str)
    return str

def outputClassAttrs(moduleName, className):
    x = pychart.doc_support.modules[moduleName]
    v = x[className]
    keys = v.keys.keys()
    keys.sort()
    for key in keys:
        if key[0] == '_':
            continue
        val = v.keys[key]

        type_str = pychart.doc_support.stringify_type(val[0])

        print "\\begin{memberdesc}{%s}\n\\textbf{Type:} %s" % (key, type_str)
        if False:
            print "\\label{%s.%s.%s}" % (moduleName.replace("_","-"),
                                         className.replace("_","-"),
                                         key.replace("_", "-"))
	mm = re.match("(.*)\\.T$", str(type_str))
	if mm:
	    print "(\\pxref{module-%s})" % re.sub("_", "-", mm.group(1))

        if len(val) > 3:
            print "\\textbf{Default:} %s." % format_doc_string(val[3]),
        else:
            print "\\textbf{Default:} %s." % format_doc_string(str(pychart.doc_support.stringify_value(val[1]))),

        print ""
        print ""

        if len(val) > 2:
            print format_doc_string(val[2])

	print "\\end{memberdesc}"
    #print "@end multitable";

def copy_file(src, dest):
    sys.stderr.write("%s->%s\n" % (src, dest))
    infp = open(src, "rb")
    outfp = open(dest, "wb")
    outfp.writelines(infp.readlines())
    infp.close()
    outfp.close()

nodeNames = []
nodeReplaces = []
demoDir = pychart_dir + "/demos/"

def scan_nodes(fp):
    global nodeNames
    for line in fp.readlines():
        mo_node = re.match("^@node ([^,]*)", line)
        if mo_node:
            nodeNames.append(re.compile("\\b(" + mo_node.group(1) + ")\\b"))

def include_text_file(file):
    fp = open(file, "r")
    print "\\noindent\\bfcode{%s}\n\n" % file
    print "\\begin{verbatim}"

    line = fp.readline()
    if line.startswith('#'):
        # Skip the first comment block. It's usually a copyright statement.
        while True:
            line = fp.readline()
            assert line
            if not line.startswith('#'):
                break
    print line,
    for line in fp.readlines():
        line = string.expandtabs(line)
        print line,
    fp.close()
    print "\\end{verbatim}"

def format_doc(str):
    out = ""
    empty_line_found = False
    in_example = None

    for line in string.split(str, "\n"):
        if empty_line_found and len(line) > 0 and line[0] != ' ':
            if not in_example:
                out = out + "\\begin{verbatim}\n"
                in_example = True
            out = out + line + "\n"
        else:
            if line == "":
                empty_line_found = True

            if in_example:
                out = out + line + "\n\\end{verbatim}\n"
            else:
                # Do some formatting.
                line = format_doc_string(line)
                out = out + line + "\n"
            in_example = None
    if in_example:
        out = out + "\n\end{verbatim}\n"
    return out

fp = open(argv[0], "r")

scan_nodes(fp)

fp.seek(0)

while True:
    line = fp.readline()
    if line == "": break

    mo7 = re.match("@xximage\\{(.*),\\}", line)

    line = line.replace("@chart{}", "PyChart")
    line = line.replace("@shadow", "Parameter \\var{shadow} is either None or tuple (\\var{xdelta, ydelta, shadowstyle}). If non-None, a shadow of \\var{shadowstyle} (\\pxref{module-fill-style}) is drawn beneath the polygon at the offset (\\var{xdelta, ydelta}).")

    mo = re.match("^%%([^.]+)\\.(.*)", line)
    if mo:
        outputClassAttrs(mo.group(1), mo.group(2))
        continue

    mo = re.match("^@samplechartandcode\{([^,]*),(.*)\}", line)

    if mo:
        basename = mo.group(1)
        description = mo.group(2)
        for ext in ["png", "eps", "pdf"]:
            copy_file("%s%s-c.%s" % (demoDir, basename, ext),
                      "%s.%s" % (basename, ext))

        print "\\includegraphics{%s}\n" % (basename)
        print description, "\n"
        print "Below is the source code that produces the above chart."
        include_text_file(demoDir + basename + ".py")
        continue

    mo = re.match("^@samplecode\{(.*)\}", line)
    if mo:
        basename = mo.group(1)
        include_text_file(demoDir + basename + ".py")
        continue

    mo = re.match("^@samplechart\{(.*)\}", line)
    if mo:
        basename = mo.group(1)
        for ext in ["png", "eps", "pdf"]:
            copy_file("%s%s-c.%s" % (demoDir, basename, ext),
                      "%s.%s" % (basename, ext))
        print "\\includegraphics{%s}\n" % (basename)
        continue

    mo = re.match("^@pydescribe\{(.*)\}", line)
    if mo:
        obj_name = mo.group(1)
        obj = eval(obj_name)
        print format_doc(str(obj.__doc__)), "\n"
        continue

    print line,



#
# Copyright (C) 2000-2005 by Yasushi Saito (yasushi.saito@gmail.com)
#
# Pychart is free software; you can redistribute it and/or modify it
# under the terms of the GNU General Public License as published by the
# Free Software Foundation; either version 2, or (at your option) any
# later version.
#
# Pychart is distributed in the hope that it will be useful, but WITHOUT
# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
# FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
# for more details.
#
from pychart import *
theme.get_options()

data = chart_data.read_csv("lines.csv")

xaxis=axis.X(label="X", tic_interval=10)
yaxis=axis.Y(label="Y", tic_interval=10)
ar = area.T(x_range=(0,100), y_range=(0,100), x_axis=xaxis, y_axis=yaxis)
eb = error_bar.error_bar2(tic_len=5, hline_style=line_style.gray50)
ar.add_plot(line_plot.T(label="foo", data=data, error_bar=eb, y_error_minus_col=3),
            line_plot.T(label="bar", data=data, ycol=2, error_bar=eb, y_error_minus_col=3))
ar.draw()

tb = text_box.T(loc=(40, 130), text="This is\nimportant!", line_style=None)
tb.add_arrow((ar.x_pos(data[6][0]), ar.y_pos(data[6][1])), "cb")
tb.draw()

ar = area.T(loc=(200, 0), x_range=(0,100), y_range=(0,100),
            x_axis=xaxis, y_axis=yaxis, legend=legend.T())
ar.add_plot(line_plot.T(label="foo", data=data, data_label_format="/8{}%d"),
            line_plot.T(label="bar", data=data, ycol=2))
ar.draw()



#
# Copyright (C) 2000-2005 by Yasushi Saito (yasushi.saito@gmail.com)
#
# Pychart is free software; you can redistribute it and/or modify it
# under the terms of the GNU General Public License as published by the
# Free Software Foundation; either version 2, or (at your option) any
# later version.
#
# Pychart is distributed in the hope that it will be useful, but WITHOUT
# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
# FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
# for more details.
#
from pychart import *
theme.get_options()

data = [("Foo", (10, 7, 10, 5, 5, 12, 13, 5, 10, 3),
         (7,10,8,16,9,3)),
        ("Bar", (5, 10, 12, 10, 9, 3),
         (10,10,13,6,9,13),)]

ar = area.T(y_coord = category_coord.T(data, 0),
            x_grid_style=line_style.gray50_dash1,
            x_grid_interval=20, x_range = (0,100),
            x_axis=axis.X(label="X label"),
            y_axis=axis.Y(label="Y label"),
            legend = legend.T(loc=(80, 40)))

chart_object.set_defaults(interval_bar_plot.T, direction="horizontal",
                          width=3, cluster_sep = 5, data=data)
ar.add_plot(interval_bar_plot.T(line_styles = [line_style.default, None],
                                fill_styles = [fill_style.red, None],
                                label="foo", cluster=(0,2)),
            interval_bar_plot.T(line_styles = [line_style.default, None],
                                fill_styles = [fill_style.blue, None],
                                label="bar", hcol=2, cluster=(1,2)))

can = canvas.default_canvas()
can.set_title("Interval bar test")
can.set_author("John Doe")
ar.draw()



#
# Copyright (C) 2000-2005 by Yasushi Saito (yasushi.saito@gmail.com)
#
# Pychart is free software; you can redistribute it and/or modify it
# under the terms of the GNU General Public License as published by the
# Free Software Foundation; either version 2, or (at your option) any
# later version.
#
# Pychart is distributed in the hope that it will be useful, but WITHOUT
# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
# FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
# for more details.
#
from pychart import *

data = [ (0, 10, 30, 40, 60), (10, 20, 40, 50, 55), (20, 10, 35, 38, 43),
         (30, 8, 30, 35, 39), (40, 8, 20, 28, 39) ]

ar = area.T(x_axis = axis.X(label="X axis"),
            y_grid_interval = 10, y_grid_style = line_style.white,
            y_axis = axis.Y(label="Y axis"),
            y_grid_over_plot=1, legend = legend.T())

if theme.use_color:
    colors = [ fill_style.darkseagreen, fill_style.white, fill_style.brown ]
else:
    colors = [ fill_style.gray90, fill_style.white, fill_style.gray50 ]
ar.add_plot(range_plot.T(label="foo", data=data, fill_style = colors[0]))
ar.add_plot(range_plot.T(label="bar", data=data, min_col=2, max_col=3,
                         fill_style = colors[1]))
ar.add_plot(range_plot.T(label="baz", data=data, min_col=3, max_col=4,
                         fill_style = colors[2]))
ar.draw()



#
# Copyright (C) 2000-2005 by Yasushi Saito (yasushi.saito@gmail.com)
#
# Pychart is free software; you can redistribute it and/or modify it
# under the terms of the GNU General Public License as published by the
# Free Software Foundation; either version 2, or (at your option) any
# later version.
#
# Pychart is distributed in the hope that it will be useful, but WITHOUT
# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
# FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
# for more details.
#
from pychart import *

class zap_y_coord(linear_coord.T):
    # Method get_data_range is inherited from linear_coord.T.
    def get_canvas_pos(self, size, val, min, max):
        # Zap Y values between 70 and 240.
        # Thus, Y axis will display 0..70 and 240..280, 110 points total.
        if val <= 70:
            return linear_coord.T.get_canvas_pos(self, size, val, 0, 110)
        elif val <= 240:
            return linear_coord.T.get_canvas_pos(self, size, 70, 0, 110)
        else:
            return linear_coord.T.get_canvas_pos(self, size, val - 170, 0, 110)
    def get_tics(self, min, max, interval):
        # Don't draw tick marks between 65 and 245.
        tics = linear_coord.T.get_tics(self, min, max, interval)
        return [x for x in tics if x < 65 or x > 256]

can = canvas.default_canvas()
theme.get_options()
data = [(10, 20, 30, 5), (20, 265, 33, 5),
        (30, 255, 30, 5), (40, 45, 51, 7), (50, 25, 27, 3)]

chart_object.set_defaults(area.T, size = (150, 120), y_range = (0, 280),
                          y_coord = zap_y_coord(),
                          x_coord = category_coord.T(data, 0))
chart_object.set_defaults(bar_plot.T, data = data)

bar_plot.fill_styles.reset();
plot1=bar_plot.T(label="foo", cluster=(0,3))
plot2=bar_plot.T(label="bar", hcol=2, cluster=(1,3))
plot3=bar_plot.T(label="baz", hcol=3, cluster=(2,3))

ar = area.T(loc=(250,0),
            x_axis=axis.X(label="X label", format="/a-30{}%d"),
            y_axis=axis.Y(label="Y label", tic_interval=10))
ar.add_plot(plot1, plot2, plot3)
ar.draw()
for x in (ar.x_pos(10) - 20, ar.x_pos(20)- 10, ar.x_pos(30) - 10):
    zap.zap_horizontally(can, line_style.default, fill_style.white,
                         x, ar.y_pos(65), x+16, ar.y_pos(65) + 4, 4, 4)



#
# Copyright (C) 2000-2005 by Yasushi Saito (yasushi.saito@gmail.com)
# 
# Pychart is free software; you can redistribute it and/or modify it
# under the terms of the GNU General Public License as published by the
# Free Software Foundation; either version 2, or (at your option) any
# later version.
#
# Pychart is distributed in the hope that it will be useful, but WITHOUT
# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
# FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
# for more details.
#
from pychart import *
data = [(10, 20, 5, 5), (20, 65, 5, 5),
        (30, 55, 4, 4), (40, 45, 2, 2), (50, 25, 3, 3)]

ar = area.T(x_axis = axis.X(label = "X label"),
            y_axis = axis.Y(label = "Y label"))
ar.add_plot(bar_plot.T(label="foo", data = data,
                       fill_style = fill_style.gray90,
                       error_bar = error_bar.bar3,
                       error_minus_col = 2,
                       error_plus_col = 3))
canvas.default_canvas().set_background(fill_style.diag, -100, -100, 300, 300)
ar.draw()




#
# Copyright (C) 2000-2005 by Yasushi Saito (yasushi.saito@gmail.com)
# 
# Pychart is free software; you can redistribute it and/or modify it
# under the terms of the GNU General Public License as published by the
# Free Software Foundation; either version 2, or (at your option) any
# later version.
#
# Pychart is distributed in the hope that it will be useful, but WITHOUT
# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
# FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
# for more details.
#
from pychart import *
import tocslib

size=120

can = canvas.default_canvas()

arrow.T(line_style=line_style.T(width=1)).draw([(0,0),(0,size)])
arrow.T(line_style=line_style.T(width=1)).draw([(0,0),(size,0)])
font.defaultSize=10
font.defaultLineHeight=8
can.show(-5,60,"/hC/a90/oManageability")
can.show(10,-3, "/hL/vT/oPerformance&availability\n/o//cost")

def circle(x,y,str):
    can.ellipsis(line_style.default, fill_style.black, x, y, 2)
    can.show(x+5,y, "/T/vM" + str)

circle(size*0.2,size*0.8,"/l8Monolithic\n/l8Server")
circle(size*0.4,size*0.6,"/l8Cluster-based\n/l8operating system")
circle(size*0.6,size*0.4,"/l8Distributed\n/l8file system")
circle(size*0.8,size*0.2,"/l8Static\n/l8partitioning")
circle(size*0.8,size*0.8,"Porcupine");




#
# Copyright (C) 2000-2005 by Yasushi Saito (yasushi.saito@gmail.com)
# 
# Pychart is free software; you can redistribute it and/or modify it
# under the terms of the GNU General Public License as published by the
# Free Software Foundation; either version 2, or (at your option) any
# later version.
#
# Pychart is distributed in the hope that it will be useful, but WITHOUT
# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
# FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
# for more details.
#
from pychart import *
import copy

width=pychart_util.inch_to_point(1.7)
height=pychart_util.inch_to_point(1.2)
loc2 = (width+36, 0)

def label(ar, text):
    return text_box.T(text=text, line_style = None, loc=(ar.loc[0]+ar.size[0]/2, ar.loc[1]-40))

tickSize=3
lWidth=1.2
def get_tick_mark(p):
    if p == "PN":
        return tick_mark.Diamond(size=tickSize)
    elif p == "PRV":
        return tick_mark.Triangle(size=tickSize)
    elif p == "PR":
        return tick_mark.X(size=tickSize*1.2,line_style=line_style.T(width=1))
    elif p == "SP" or p == "SM":
        return tick_mark.Square(size=tickSize)
    elif p == "D4":
        return tick_mark.Diamond(size=tickSize)
    elif p == "D2":
        return tick_mark.DownTriangle(size=tickSize)
    elif p == "D1":
        return tick_mark.Square(size=tickSize)
    elif p == "R":
        return tick_mark.Circle(size=tickSize)
    elif p == "S4":
        return tick_mark.Diamond(size=tickSize)
    elif p == "S2":
        return tick_mark.Plus(size=tickSize)
    elif p == "S1":
        return tick_mark.Square(size=tickSize)
    else:
        return None
    #else:
    #    pychart_util.error("tick_mark:", p)

greyscale_line_styles = {
    "PN" : line_style.T(width=lWidth),
    "PRV": line_style.T(width=lWidth,color=color.gray50),
    "PR": line_style.T(width=lWidth,dash=line_style.dash1),
    "D4": line_style.T(width=lWidth),
    "D2": line_style.T(width=lWidth,dash=line_style.dash1, color=color.gray70),
    "D1": line_style.T(width=lWidth,dash=line_style.dash2),
    "S4": line_style.T(width=lWidth),
    "S2": line_style.T(width=lWidth,dash=line_style.dash1,color=color.gray70),
    "S1": line_style.T(width=lWidth,dash=line_style.dash2,color=color.gray70),
    "R": line_style.T(width=lWidth,color=color.gray50),
    "SM": line_style.T(width=lWidth),
    "SP": line_style.T(width=lWidth),
    }

def hack(l):
    x = copy.deepcopy(l)
    x.width = lWidth
    return x
    
color_line_styles = {
    "PN" : hack(line_style.standards.nth(0)),
    "PRV":  hack(line_style.standards.nth(1)),
    "PR":  hack(line_style.standards.nth(2)),
    "D4":  hack(line_style.standards.nth(3)),
    "D2":  hack(line_style.standards.nth(4)),
    "D1":  hack(line_style.standards.nth(5)),
    "S4":  hack(line_style.standards.nth(6)),
    "S2":  hack(line_style.standards.nth(7)),
    "S1":  hack(line_style.standards.nth(8)),
    "R":  hack(line_style.standards.nth(9)),
    "SM":  hack(line_style.standards.nth(10)),
    "SP":  hack(line_style.standards.nth(11)),
    }

def get_line_style(p):
    if not theme.use_color:
        styles = greyscale_line_styles
    else:
        styles = color_line_styles
    if styles.has_key(p):
        return styles[p]
    else:
        pychart_util.error("unknown policy:", p)

width2=pychart_util.inch_to_point(2.1)
height=pychart_util.inch_to_point(1.2)
xlabel_offset=-35



#
# Copyright (C) 2000-2005 by Yasushi Saito (yasushi.saito@gmail.com)
# 
# Pychart is free software; you can redistribute it and/or modify it
# under the terms of the GNU General Public License as published by the
# Free Software Foundation; either version 2, or (at your option) any
# later version.
#
# Pychart is distributed in the hope that it will be useful, but WITHOUT
# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
# FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
# for more details.
#
from pychart import *
import tocslib
ymin=0

width=tocslib.width
height=tocslib.height

def CreateSkewGraph(data, ymax, interval):
    return area.T(x_coord=category_coord.T(data, 0),
                  size=(width, height),
                  x_axis = axis.X(label="/bSkew"),
                  y_axis = axis.Y(label="", tic_interval=interval,
                                  label_offset=(-40,None)),
                  y_range=(ymin, ymax),
                  legend=None)

data = chart_data.read_str(" ",
    "0 689.2780916 791.9442379 778.0596226 693.2 734.99 766.8875721 753.09 289.93",
    "0.25 690.984838 801.0757878 812.0217771 705.3 383.4590857 418.7825131 463.6420009 148.26",
    "0.5 683.2219825 769.5098419 784.2037828 710.23 190.9876947 217.3046324 274.7908102 75.13",
    "1 694.9 780.03 780.02 716 26.37 49.13 89.86 12.03784649")

def create_line_plot(label, data, col):
    return line_plot.T(label=label, data=data, ycol=col,
                      tick_mark=tocslib.get_tick_mark(label),
                      line_style=tocslib.get_line_style(label))

ar = CreateSkewGraph(data, 1000, 200)
ar.y_axis.label = "/bMessages//second"
ar.legend = legend.T(loc=(50+width*2, 0), shadow=(2,-2,fill_style.gray50))
ar.add_plot(create_line_plot("D4", data, 3),
            create_line_plot("D2", data, 2),
            create_line_plot("D1", data, 1),
            create_line_plot("R", data, 4),
            create_line_plot("S4", data, 7),
            create_line_plot("S2", data, 6),
            create_line_plot("S1", data, 5),
            create_line_plot("SM", data, 8))
ar.draw()
tocslib.label(ar, "(a)").draw()

data = chart_data.read_str(" ",
                    "0 327.88 362.53 373.34 325.0067623 322.89 360.4 363.23",
                    "0.25 330.2 355.671277 353.1399808 315.9811765 165.0281937 177.9464914 192.3867494",
                    "0.5 325.8804905 345.7156968 351.6724777 318.34 78.83 109.29 138.27",
                    "1 323.0343 352.83 353.31 323.93 20.37 48.334 77.45")

ar = CreateSkewGraph(data, 400, 100)
ar.loc = tocslib.loc2
ar.add_plot(create_line_plot("D4", data, 3),
            create_line_plot("D2", data, 2),
            create_line_plot("D1", data, 1),
            create_line_plot("R", data, 4),
            create_line_plot("S4", data, 7),
            create_line_plot("S2", data, 6),
            create_line_plot("S1", data, 5))

ar.draw()
tocslib.label(ar, "(b)").draw()



#
# Copyright (C) 2000-2005 by Yasushi Saito (yasushi.saito@gmail.com)
# 
# Pychart is free software; you can redistribute it and/or modify it
# under the terms of the GNU General Public License as published by the
# Free Software Foundation; either version 2, or (at your option) any
# later version.
#
# Pychart is distributed in the hope that it will be useful, but WITHOUT
# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
# FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
# for more details.
#
from pychart import *
import tocslib

data = chart_data.read_str(" ",
                    "2 56.11176043 19.72962276 26.27090859 14.99",
                    "4 108.040603 41.39483239 55.59 47.5618015",
                    "8 224.4335486 80.348324 110.23 89.62",
                    "16 425.6517423 148.7731912 207.34 169.24",
                    "30 790.9817461 273.8225464 385.24 289.93")

ar = area.T(size=(tocslib.width2, tocslib.height),
            x_axis = axis.X(label="/bCluster size"),
            y_axis = axis.Y(label="/bMessages//second", tic_interval=200,
                            label_offset=(tocslib.xlabel_offset, None)),
            legend=legend.T())
ar.add_plot(line_plot.T(label="Porcupine no replication",
                        tick_mark=tocslib.get_tick_mark("PN"),
                        line_style=tocslib.get_line_style("PN"),
                        data=data, ycol=1),
             line_plot.T(label="Porcupine with\nreplication, NVRAM",
                        tick_mark=tocslib.get_tick_mark("PRV"),
                        line_style=tocslib.get_line_style("PRV"),
                        data=data, ycol=3),
             line_plot.T(label="Porcupine with replication",
                        tick_mark=tocslib.get_tick_mark("PR"),
                        line_style=tocslib.get_line_style("PR"),
                        data=data, ycol=2),
             line_plot.T(label="Sendmail+popd",
                        data=data, ycol=4,
                        tick_mark=tocslib.get_tick_mark("SP"),
                        line_style=tocslib.get_line_style("SP")))

ar.draw()




#
# Copyright (C) 2000-2005 by Yasushi Saito (yasushi.saito@gmail.com)
# 
# Pychart is free software; you can redistribute it and/or modify it
# under the terms of the GNU General Public License as published by the
# Free Software Foundation; either version 2, or (at your option) any
# later version.
#
# Pychart is distributed in the hope that it will be useful, but WITHOUT
# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
# FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
# for more details.
#
from pychart import *
import failure

can = canvas.default_canvas()
can.round_rectangle(line_style.gray70_dash1, None, -60, 140, 280, 180, 10)
can.show(200, 142, "/H{}/14{}text_box.T")

tb = text_box.T(text="/H{}/14{}axis.X", loc=(-80, 0), line_style = None)
tb.add_arrow((0, 25), "rm", arrow=arrow.fat1)
tb.draw()

tb = text_box.T(text="/H{}/14{}axis.Y", loc=(00, -45), line_style = None)
tb.add_arrow((30, 0), "ct", arrow=arrow.fat1)
tb.draw()

tb = text_box.T(text="/H{}/14{}legend.T", loc=(240, 100), line_style = None)
tb.add_arrow((250, 80), "cb", arrow=arrow.fat1)
tb.draw()

tb = text_box.T(text="/o{}/14{}plots", loc=(180, 100), line_style = None)
tb.add_arrow((170, 70), "lb", arrow=arrow.fat1)
tb.draw()




from distutils.core import setup
import pychart.version

setup (name = "PyChart",
       version = pychart.version.version,
       description = "Python Chart Generator",
       author = "Yasushi Saito",
       author_email = "yasushi@cs.washington.edu",
       url = "http://www.hpl.hp.com/personal/Yasushi_Saito/pychart",
       license = "GPL",
       long_description = """
Pychart is a Python library for creating high-quality
charts in Postscript, PDF, PNG, and SVG. 
It produces line plots, bar plots, range-fill plots, and pie
charts.""",
       packages = ['pychart', 'pychart.afm']
      )



#
# Copyright (C) 2000-2005 by Yasushi Saito (yasushi.saito@gmail.com)
# 
# Pychart is free software; you can redistribute it and/or modify it
# under the terms of the GNU General Public License as published by the
# Free Software Foundation; either version 2, or (at your option) any
# later version.
#
# Pychart is distributed in the hope that it will be useful, but WITHOUT
# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
# FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
# for more details.
#
from pychart import *
import pychart.doc_support
import re

can = canvas.default_canvas()

x = 100
y = 500

ar = area.T()

q=30
m=60

def draw_error_bar(e):
    global x, y
    name = pychart.doc_support.stringify_value(e)
    name = re.sub("error_bar\\.", "", name)
    tb = text_box.T(text="/hC" + name, loc=(x, y-m-20), line_style=None)
    tb.draw()
    e.draw(can, (x, y), y-m, y+m, y-q, y+q)
    x = x + 50

xmin = x

for e in error_bar.standards.list():
    draw_error_bar(e)

xmax = x

can.line(line_style.gray70_dash1, xmin-20, y, xmax, y)

can.line(line_style.gray70_dash1, xmin-20, y-q, xmax, y-q)
can.line(line_style.gray70_dash1, xmin-20, y+q, xmax, y+q)
tb = text_box.T(text="quartile", loc=(xmax+40, y), line_style=None)
tb.add_arrow(tipLoc=(xmax+55, y+q)) #, tail='tc')
tb.add_arrow(tipLoc=(xmax+55, y-q)) #, tail='bc')
tb.draw()

tb = text_box.T(text="min//\nmax", loc=(xmax+80, y), line_style=None)
tb.add_arrow(tipLoc=(xmax+95, y+m)) #, tail='tc')
tb.add_arrow(tipLoc=(xmax+95, y-m)) #, tail='bc')
tb.draw()




#
# Copyright (C) 2000-2005 by Yasushi Saito (yasushi.saito@gmail.com)
#
# Pychart is free software; you can redistribute it and/or modify it
# under the terms of the GNU General Public License as published by the
# Free Software Foundation; either version 2, or (at your option) any
# later version.
#
# Pychart is distributed in the hope that it will be useful, but WITHOUT
# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
# FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
# for more details.
#
from pychart import *
theme.get_options()

data = [(10, 20, 30), (20, 65, 33),
	(30, 55, 30), (40, 45, 51),
	(50, 25, 27), (60, 75, 30)]

ar = area.T(size = (150,120),
            y_grid_interval=10,
            x_axis=axis.X(label="X label", label_offset=(0,-7)),
            y_axis=axis.Y(label="Y label"),
            legend = legend.T(), y_range = (0, None))

ar.add_plot(bar_plot.T(label="foo", data=data),
            line_plot.T(label="bar", data=data, ycol=2))
ar.draw()



#
# Copyright (C) 2000-2005 by Yasushi Saito (yasushi.saito@gmail.com)
# 
# Pychart is free software; you can redistribute it and/or modify it
# under the terms of the GNU General Public License as published by the
# Free Software Foundation; either version 2, or (at your option) any
# later version.
#
# Pychart is distributed in the hope that it will be useful, but WITHOUT
# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
# FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
# for more details.
#
from pychart import *
import tocslib

def create_line_plot(label, ycol):
    return line_plot.T(label=label,
                      tick_mark=tocslib.get_tick_mark(label),
                      line_style=tocslib.get_line_style(label),
                      data=data, ycol=ycol)

def create_graph(data):
    ar = area.T(size=(tocslib.width, tocslib.height),
                x_range = (1,3),
                x_axis = axis.X(label="/bNumber of nodes with fast disks"),
                y_axis = axis.Y(label="/bIncrease in\nMessages//second", 
                                label_offset=(tocslib.xlabel_offset, None)),
                legend=legend.T())
    
    ar.add_plot(create_line_plot("D4", 2),
                create_line_plot("D2", 1),
                create_line_plot("S4", 5),
                create_line_plot("S2", 4),
                create_line_plot("R", 3))

    return ar

data = chart_data.read_str(" ",
                           "0 0 0 0 0 0 0",
                           "1 45 63 2 9 30",
                           "2 118 133 3 20 53",
                           "3 174 194 3 31 71")
ar = create_graph(data)
ar.y_range = (0,200)
ar.y_axis.tic_interval=50
ar.legend=None
ar.draw()

tocslib.label(ar, "(a)").draw()

data = chart_data.read_str(" ",
                           "0 0 0 0 0 0 0",
                           "1 10 26.5 2 4 9",
                           "2 29 53 3 10 18",
                           "3 48 79 3 16 28")

ar = create_graph(data)
ar.y_range = (0,100)
ar.y_axis.label=None
ar.y_axis.tic_interval=25
ar.loc = tocslib.loc2
ar.draw()

tocslib.label(ar, "(b)").draw()



# -*- coding: utf-8 -*-
#
# Copyright (C) 2005 by Yasushi Saito (yasushi.saito@gmail.com)
# 
# Pychart is free software; you can redistribute it and/or modify it
# under the terms of the GNU General Public License as published by the
# Free Software Foundation; either version 2, or (at your option) any
# later version.
#
# Pychart is distributed in the hope that it will be useful, but WITHOUT
# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
# FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
# for more details.
#
from pychart import *
can = canvas.default_canvas()
x, y = (100, 500)
def show_text(str):
    global x, y
    can.show(x, y, str)
    can.show(x + 200, y, "/12/C" + font.quotemeta(str))
    y -= 20

show_text(unicode('Zürich', 'utf-8'))
show_text(unicode('X äöü Y', 'utf-8'))




#
# Copyright (C) 2000-2005 by Yasushi Saito (yasushi.saito@gmail.com)
# 
# Pychart is free software; you can redistribute it and/or modify it
# under the terms of the GNU General Public License as published by the
# Free Software Foundation; either version 2, or (at your option) any
# later version.
#
# Pychart is distributed in the hope that it will be useful, but WITHOUT
# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
# FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
# for more details.
#
from pychart import *
import pychart.doc_support
import chartdemo
import re

can = canvas.default_canvas()
x = 100
y = 100

def draw_tick(tick):
    global x, y
    name = pychart.doc_support.stringify_value(tick)
    name = re.sub("tick_mark\\.", "", name)
    name = pychart.doc_support.break_string(name)
    height = font.text_height(name)[0] + 10
    tick.draw(can, x, y+tick.size/2)
    tb = text_box.T(text="/12" + name, loc=(x, y-height), line_style=None)
    x = x + 70
    tb.draw(can)

for tick in tick_mark.standards.list():
    draw_tick(tick)
    if x >= chartdemo.MaxWidth:
        x = 100
        y = y + 45



#
# Copyright (C) 2000-2005 by Yasushi Saito (yasushi.saito@gmail.com)
# 
# Pychart is free software; you can redistribute it and/or modify it
# under the terms of the GNU General Public License as published by the
# Free Software Foundation; either version 2, or (at your option) any
# later version.
#
# Pychart is distributed in the hope that it will be useful, but WITHOUT
# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
# FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
# for more details.
#
from pychart import *
import tocslib
data = [[128, 637], [256, 651], [512, 680], [1024, 737], [2048, 851]]

ar = area.T(x_axis = axis.X(label="Hash map size", 
                            tic_interval=lambda x,y: [128,256,512,1024,2048]),
            y_axis = axis.Y(label="Recovery cost(ms)",
                            tic_interval=lambda x,y: (600,700,800,900,1000)),
            x_grid_interval = 2,
            y_range = (0, 1000),
            x_range = (100, 2400),
            legend = None,
            x_coord = log_coord.T())
ar.add_plot(bar_plot.T(data=data, label=None, data_label_format="/o/7{}%d"))
ar.draw()




#
# Copyright (C) 2000-2005 by Yasushi Saito (yasushi.saito@gmail.com)
# 
# Pychart is free software; you can redistribute it and/or modify it
# under the terms of the GNU General Public License as published by the
# Free Software Foundation; either version 2, or (at your option) any
# later version.
#
# Pychart is distributed in the hope that it will be useful, but WITHOUT
# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
# FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
# for more details.
#
from pychart import *
import pychart.doc_support
import re
x = 100
y = 500

def draw(obj):
    global x, y
    name = pychart.doc_support.stringify_value(obj)
    name = re.sub("arrow\\.", "", name)
    obj.draw(((x, y), (x, y+30)))
    tb = text_box.T(text="/hC" + name, loc=(x, y-12), line_style=None)
    tb.draw()
    x = x + 50

for style in arrow.standards.list():
    draw(style)
    
    
